Groundwater resource definitions
================================

Groundwater resources - for the purpose of the WRAP Technical Note - are defined in
``wrap_technote/resources/groundwater-resource-definitions.csv``.

.. csv-table::
    :file: ../wrap_technote/resources/groundwater-resource-definitions.csv
    :header-rows: 1


